Method: Elastictastic.config

Defined in:
lib/elastictastic.rb

.configConfiguration

Elastictastic global configuration. In a Rails environment, you can configure Elastictastic by creating a config/elastictastic.yml file, whose keys will be passed into the Configuration object when your application boots. In non-Rails environment, you can configure Elastictastic directly using the object returned by this method.

Returns:



57
58
59
# File 'lib/elastictastic.rb', line 57

def config
  @config ||= Configuration.new
end